#####################################################################
## Confidence_Intervals.R                                          ##
#####################################################################
## This script draws a specified number of random samples of a     ##
## specified size from a normal distribution with a known          ##
## population mean and standard deviation. It then computes 95%    ##
## confidence intervals for all of the samples and plots them.     ##
#####################################################################

## USER-DEFINED VARIABLES ##

## number of random samples to generate
num_samples <- 100

## size of each sample
sample_size <- 1000

## population mean
mu <- 0.253

## population standard deviation
sigma <- 0.04


## PROGRAM CODE ##

## use the standard error of the mean to calculate the Y-axis limits
std_error <- sigma/sqrt(sample_size)
y_axis_interval <- c(mu-5*std_error, mu+5*std_error)

## set the plotting options and draw a horizontal red line at the population mean
plot(c(0, num_samples), y_axis_interval, type="n", xlab="Sample number", ylab="95% CI of sample mean")
abline(h=mu, col="red")

## use a FOR loop to generate the specified number of samples
for(i in 1:num_samples) {

	## draw the sample from the random normal distribution
	sample <- rnorm(sample_size, mean=mu, sd=sigma)

	## calculate the sample mean and standard error
	sample_mean <- mean(sample)
	sample_std_error <- sd(sample)/sqrt(sample_size)

	## calculate the upper and lower limits of the 95% confidence interval
	CI_upper <- sample_mean + qt(0.975, sample_size-1)*sample_std_error
	CI_lower <- sample_mean - qt(0.975, sample_size-1)*sample_std_error

	## plot the 95% confidence interval
	points(c(i, i), c(CI_upper, CI_lower), type="b")
}

